@@ -370,7 +370,15 @@ static int myGetline(char **lineptr, int *n, FILE *stream)
   return p - *lineptr;
 }
 
-
+static void nonContiguousError(analdef *adef)
+{
+  if(adef->compressPatterns == FALSE)
+    {
+      printf("\nError: You are not allowed to use interleaved partitions, that is, assign non-contiguous sites\n");
+      printf("to the same partition model, when pattern compression is disabled via the -c flag!\n\n");
+      exit(-1);
+    }
+}
 
 void parsePartitions(analdef *adef, rawdata *rdta, tree *tr)
 {
@@ -499,6 +507,7 @@ void parsePartitions(analdef *adef, rawdata *rdta, tree *tr)
       if(*ch == ',')
 	{	     
 	  upper = lower;
+	  nonContiguousError(adef);
 	  goto SINGLE_NUMBER;
 	}
       
@@ -542,6 +551,7 @@ void parsePartitions(analdef *adef, rawdata *rdta, tree *tr)
       if(*ch == ',')
 	{	 
 	  ch++;
+	  nonContiguousError(adef);
 	  goto numberPairs;
 	}
       
@@ -556,13 +566,8 @@ void parsePartitions(analdef *adef, rawdata *rdta, tree *tr)
 	      exit(-1);
 	    }   
 
-	  if(adef->compressPatterns == FALSE)
-	    {
-	      printf("\nError: You are not allowed to use interleaved partitions, that is, assign non-contiguous sites\n");
-	      printf("to the same partition model, when pattern compression is disabled via the -c flag!\n\n");
-	      exit(-1);
-	    }
-	  
+	  nonContiguousError(adef);
+
 	  l = 0;
 	  while(isNum(*ch))
 	    {
@@ -582,6 +587,7 @@ void parsePartitions(analdef *adef, rawdata *rdta, tree *tr)
 	  if(*ch == ',')
 	    {	       
 	      ch++;
+	      nonContiguousError(adef);
 	      goto numberPairs;
 	    }
 	}  
